'use client';

import { useState, useEffect } from 'react';
import { motion } from 'framer-motion';
import { FiUsers, FiBook, FiAward, FiBarChart2, FiTrendingUp } from 'react-icons/fi';
import { getAnalytics } from '@/utils/firebase_utils';
import type { Analytics } from '@/types/education';

export default function AnalyticsPage() {
  const [analytics, setAnalytics] = useState<Analytics>({
    totalUsers: 0,
    totalSubjects: 0,
    totalTopics: 0,
    totalContent: 0,
    activeUsers: 0,
    completionRate: 0,
    engagementRate: 0
  });
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    loadAnalytics();
  }, []);

  const loadAnalytics = async () => {
    try {
      setLoading(true);
      const data = await getAnalytics();
      setAnalytics(data);
    } catch (error) {
      console.error('Error loading analytics:', error);
    } finally {
      setLoading(false);
    }
  };

  const stats = [
    {
      title: 'Total Users',
      value: analytics.totalUsers,
      icon: <FiUsers className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37]'
    },
    {
      title: 'Active Users',
      value: analytics.activeUsers,
      icon: <FiTrendingUp className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37] opacity-90'
    },
    {
      title: 'Total Subjects',
      value: analytics.totalSubjects,
      icon: <FiBook className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37] opacity-80'
    },
    {
      title: 'Total Topics',
      value: analytics.totalTopics,
      icon: <FiAward className="w-6 h-6" />,
      color: 'from-[#FF6B2B] to-[#FF8C37] opacity-70'
    }
  ];

  if (loading) {
    return (
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
        {[1, 2, 3, 4].map((i) => (
          <div key={i} className="bg-[#1a1a1a] p-6 rounded-lg animate-pulse">
            <div className="h-6 w-32 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-8 w-24 bg-[#2a2a2a] rounded"></div>
          </div>
        ))}
      </div>
    );
  }

  return (
    <div className="space-y-8">
      {/* Header */}
      <div className="flex justify-between items-center">
        <div>
          <h1 className="text-2xl font-bold text-white">Analytics Overview</h1>
          <p className="text-gray-400">Monitor platform performance and user engagement</p>
        </div>
        <motion.button
          whileHover={{ scale: 1.02 }}
          whileTap={{ scale: 0.98 }}
          onClick={() => loadAnalytics()}
          className="px-4 py-2 bg-[#1a1a1a] text-white rounded-lg hover:bg-[#2a2a2a] 
            flex items-center space-x-2"
        >
          <FiBarChart2 className="w-5 h-5" />
          <span>Refresh Data</span>
        </motion.button>
      </div>

      {/* Stats Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
        {stats.map((stat, index) => (
          <motion.div
            key={stat.title}
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: index * 0.1 }}
            className={`bg-gradient-to-br ${stat.color} p-6 rounded-lg shadow-lg`}
          >
            <div className="flex items-center justify-between">
              <div>
                <p className="text-white text-sm font-medium">{stat.title}</p>
                <p className="text-white text-2xl font-bold mt-2">{stat.value}</p>
              </div>
              <div className="bg-white/10 p-3 rounded-lg">
                {stat.icon}
              </div>
            </div>
          </motion.div>
        ))}
      </div>

      {/* Performance Metrics */}
      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        {/* Completion Rate */}
        <div className="bg-[#1a1a1a] rounded-lg p-6">
          <h2 className="text-lg font-semibold text-white mb-4">Completion Rate</h2>
          <div className="flex items-center justify-between">
            <div className="flex-1">
              <div className="h-2 bg-[#2a2a2a] rounded-full">
                <div 
                  className="h-2 bg-[#FF6B2B] rounded-full"
                  style={{ width: `${analytics.completionRate}%` }}
                ></div>
              </div>
            </div>
            <span className="ml-4 text-2xl font-bold text-white">
              {analytics.completionRate}%
            </span>
          </div>
        </div>

        {/* Engagement Rate */}
        <div className="bg-[#1a1a1a] rounded-lg p-6">
          <h2 className="text-lg font-semibold text-white mb-4">Engagement Rate</h2>
          <div className="flex items-center justify-between">
            <div className="flex-1">
              <div className="h-2 bg-[#2a2a2a] rounded-full">
                <div 
                  className="h-2 bg-[#FF6B2B] rounded-full"
                  style={{ width: `${analytics.engagementRate}%` }}
                ></div>
              </div>
            </div>
            <span className="ml-4 text-2xl font-bold text-white">
              {analytics.engagementRate}%
            </span>
          </div>
        </div>
      </div>
    </div>
  );
} 